# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['K8sApplicationArgs', 'K8sApplication']

@pulumi.input_type
class K8sApplicationArgs:
    def __init__(__self__, *,
                 application_name: pulumi.Input[str],
                 cluster_id: pulumi.Input[str],
                 application_descriotion: Optional[pulumi.Input[str]] = None,
                 command: Optional[pulumi.Input[str]] = None,
                 command_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 edas_container_version: Optional[pulumi.Input[str]] = None,
                 envs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 image_url: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_port: Optional[pulumi.Input[int]] = None,
                 internet_slb_protocol: Optional[pulumi.Input[str]] = None,
                 internet_target_port: Optional[pulumi.Input[int]] = None,
                 jdk: Optional[pulumi.Input[str]] = None,
                 limit_m_cpu: Optional[pulumi.Input[int]] = None,
                 limit_mem: Optional[pulumi.Input[int]] = None,
                 liveness: Optional[pulumi.Input[str]] = None,
                 local_volume: Optional[pulumi.Input[str]] = None,
                 logical_region_id: Optional[pulumi.Input[str]] = None,
                 mount_descs: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 nas_id: Optional[pulumi.Input[str]] = None,
                 package_type: Optional[pulumi.Input[str]] = None,
                 package_url: Optional[pulumi.Input[str]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 post_start: Optional[pulumi.Input[str]] = None,
                 pre_stop: Optional[pulumi.Input[str]] = None,
                 readiness: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[int]] = None,
                 requests_m_cpu: Optional[pulumi.Input[int]] = None,
                 requests_mem: Optional[pulumi.Input[int]] = None,
                 web_container: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a K8sApplication resource.
        :param pulumi.Input[str] application_name: The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        :param pulumi.Input[str] cluster_id: The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        :param pulumi.Input[str] application_descriotion: The description of the application
        :param pulumi.Input[str] command: The set command, if set, will replace the startup command in the mirror when the mirror is started.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command_args: Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        :param pulumi.Input[str] edas_container_version: EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] envs: Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        :param pulumi.Input[str] image_url: Mirror address. When the package_type is set to 'Image', this parameter item is required.
        :param pulumi.Input[str] internet_slb_id: Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_slb_port: The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] internet_slb_protocol: The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_target_port: The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] jdk: The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        :param pulumi.Input[int] limit_m_cpu: The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        :param pulumi.Input[int] limit_mem: The memory limit of the application instance during application operation, unit: M.
        :param pulumi.Input[str] liveness: Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        :param pulumi.Input[str] local_volume: The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        :param pulumi.Input[str] logical_region_id: The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        :param pulumi.Input[str] mount_descs: Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        :param pulumi.Input[str] namespace: The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        :param pulumi.Input[str] nas_id: The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        :param pulumi.Input[str] package_type: Application package type. Optional parameter values include: FatJar, WAR and Image.
        :param pulumi.Input[str] package_url: The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        :param pulumi.Input[str] package_version: The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        :param pulumi.Input[str] post_start: Execute script after startup
        :param pulumi.Input[str] pre_stop: Execute script before stopping
        :param pulumi.Input[str] readiness: Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        :param pulumi.Input[int] replicas: Number of application instances.
        :param pulumi.Input[int] requests_m_cpu: When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        :param pulumi.Input[int] requests_mem: When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        :param pulumi.Input[str] web_container: The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        pulumi.set(__self__, "application_name", application_name)
        pulumi.set(__self__, "cluster_id", cluster_id)
        if application_descriotion is not None:
            pulumi.set(__self__, "application_descriotion", application_descriotion)
        if command is not None:
            pulumi.set(__self__, "command", command)
        if command_args is not None:
            pulumi.set(__self__, "command_args", command_args)
        if edas_container_version is not None:
            pulumi.set(__self__, "edas_container_version", edas_container_version)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if internet_slb_id is not None:
            warnings.warn("""Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_id is deprecated: Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_id is not None:
            pulumi.set(__self__, "internet_slb_id", internet_slb_id)
        if internet_slb_port is not None:
            warnings.warn("""Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_port is deprecated: Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_port is not None:
            pulumi.set(__self__, "internet_slb_port", internet_slb_port)
        if internet_slb_protocol is not None:
            warnings.warn("""Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_protocol is deprecated: Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_protocol is not None:
            pulumi.set(__self__, "internet_slb_protocol", internet_slb_protocol)
        if internet_target_port is not None:
            warnings.warn("""Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_target_port is deprecated: Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_target_port is not None:
            pulumi.set(__self__, "internet_target_port", internet_target_port)
        if jdk is not None:
            pulumi.set(__self__, "jdk", jdk)
        if limit_m_cpu is not None:
            pulumi.set(__self__, "limit_m_cpu", limit_m_cpu)
        if limit_mem is not None:
            pulumi.set(__self__, "limit_mem", limit_mem)
        if liveness is not None:
            pulumi.set(__self__, "liveness", liveness)
        if local_volume is not None:
            pulumi.set(__self__, "local_volume", local_volume)
        if logical_region_id is not None:
            pulumi.set(__self__, "logical_region_id", logical_region_id)
        if mount_descs is not None:
            pulumi.set(__self__, "mount_descs", mount_descs)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if nas_id is not None:
            pulumi.set(__self__, "nas_id", nas_id)
        if package_type is not None:
            pulumi.set(__self__, "package_type", package_type)
        if package_url is not None:
            pulumi.set(__self__, "package_url", package_url)
        if package_version is not None:
            pulumi.set(__self__, "package_version", package_version)
        if post_start is not None:
            pulumi.set(__self__, "post_start", post_start)
        if pre_stop is not None:
            pulumi.set(__self__, "pre_stop", pre_stop)
        if readiness is not None:
            pulumi.set(__self__, "readiness", readiness)
        if replicas is not None:
            pulumi.set(__self__, "replicas", replicas)
        if requests_m_cpu is not None:
            pulumi.set(__self__, "requests_m_cpu", requests_m_cpu)
        if requests_mem is not None:
            pulumi.set(__self__, "requests_mem", requests_mem)
        if web_container is not None:
            pulumi.set(__self__, "web_container", web_container)

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> pulumi.Input[str]:
        """
        The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        """
        return pulumi.get(self, "application_name")

    @application_name.setter
    def application_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_name", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[str]:
        """
        The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="applicationDescriotion")
    def application_descriotion(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the application
        """
        return pulumi.get(self, "application_descriotion")

    @application_descriotion.setter
    def application_descriotion(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_descriotion", value)

    @property
    @pulumi.getter
    def command(self) -> Optional[pulumi.Input[str]]:
        """
        The set command, if set, will replace the startup command in the mirror when the mirror is started.
        """
        return pulumi.get(self, "command")

    @command.setter
    def command(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command", value)

    @property
    @pulumi.getter(name="commandArgs")
    def command_args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        """
        return pulumi.get(self, "command_args")

    @command_args.setter
    def command_args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "command_args", value)

    @property
    @pulumi.getter(name="edasContainerVersion")
    def edas_container_version(self) -> Optional[pulumi.Input[str]]:
        """
        EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        """
        return pulumi.get(self, "edas_container_version")

    @edas_container_version.setter
    def edas_container_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edas_container_version", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        """
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Mirror address. When the package_type is set to 'Image', this parameter item is required.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter(name="internetSlbId")
    @_utilities.deprecated("""Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_id")

    @internet_slb_id.setter
    def internet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_id", value)

    @property
    @pulumi.getter(name="internetSlbPort")
    @_utilities.deprecated("""Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_port(self) -> Optional[pulumi.Input[int]]:
        """
        The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_port")

    @internet_slb_port.setter
    def internet_slb_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "internet_slb_port", value)

    @property
    @pulumi.getter(name="internetSlbProtocol")
    @_utilities.deprecated("""Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_protocol")

    @internet_slb_protocol.setter
    def internet_slb_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_protocol", value)

    @property
    @pulumi.getter(name="internetTargetPort")
    @_utilities.deprecated("""Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_target_port(self) -> Optional[pulumi.Input[int]]:
        """
        The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_target_port")

    @internet_target_port.setter
    def internet_target_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "internet_target_port", value)

    @property
    @pulumi.getter
    def jdk(self) -> Optional[pulumi.Input[str]]:
        """
        The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        """
        return pulumi.get(self, "jdk")

    @jdk.setter
    def jdk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jdk", value)

    @property
    @pulumi.getter(name="limitMCpu")
    def limit_m_cpu(self) -> Optional[pulumi.Input[int]]:
        """
        The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        """
        return pulumi.get(self, "limit_m_cpu")

    @limit_m_cpu.setter
    def limit_m_cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_m_cpu", value)

    @property
    @pulumi.getter(name="limitMem")
    def limit_mem(self) -> Optional[pulumi.Input[int]]:
        """
        The memory limit of the application instance during application operation, unit: M.
        """
        return pulumi.get(self, "limit_mem")

    @limit_mem.setter
    def limit_mem(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_mem", value)

    @property
    @pulumi.getter
    def liveness(self) -> Optional[pulumi.Input[str]]:
        """
        Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        """
        return pulumi.get(self, "liveness")

    @liveness.setter
    def liveness(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "liveness", value)

    @property
    @pulumi.getter(name="localVolume")
    def local_volume(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        """
        return pulumi.get(self, "local_volume")

    @local_volume.setter
    def local_volume(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_volume", value)

    @property
    @pulumi.getter(name="logicalRegionId")
    def logical_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        """
        return pulumi.get(self, "logical_region_id")

    @logical_region_id.setter
    def logical_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logical_region_id", value)

    @property
    @pulumi.getter(name="mountDescs")
    def mount_descs(self) -> Optional[pulumi.Input[str]]:
        """
        Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        """
        return pulumi.get(self, "mount_descs")

    @mount_descs.setter
    def mount_descs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mount_descs", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="nasId")
    def nas_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        """
        return pulumi.get(self, "nas_id")

    @nas_id.setter
    def nas_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nas_id", value)

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> Optional[pulumi.Input[str]]:
        """
        Application package type. Optional parameter values include: FatJar, WAR and Image.
        """
        return pulumi.get(self, "package_type")

    @package_type.setter
    def package_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_type", value)

    @property
    @pulumi.getter(name="packageUrl")
    def package_url(self) -> Optional[pulumi.Input[str]]:
        """
        The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        """
        return pulumi.get(self, "package_url")

    @package_url.setter
    def package_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_url", value)

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        """
        return pulumi.get(self, "package_version")

    @package_version.setter
    def package_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_version", value)

    @property
    @pulumi.getter(name="postStart")
    def post_start(self) -> Optional[pulumi.Input[str]]:
        """
        Execute script after startup
        """
        return pulumi.get(self, "post_start")

    @post_start.setter
    def post_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "post_start", value)

    @property
    @pulumi.getter(name="preStop")
    def pre_stop(self) -> Optional[pulumi.Input[str]]:
        """
        Execute script before stopping
        """
        return pulumi.get(self, "pre_stop")

    @pre_stop.setter
    def pre_stop(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pre_stop", value)

    @property
    @pulumi.getter
    def readiness(self) -> Optional[pulumi.Input[str]]:
        """
        Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        """
        return pulumi.get(self, "readiness")

    @readiness.setter
    def readiness(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "readiness", value)

    @property
    @pulumi.getter
    def replicas(self) -> Optional[pulumi.Input[int]]:
        """
        Number of application instances.
        """
        return pulumi.get(self, "replicas")

    @replicas.setter
    def replicas(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "replicas", value)

    @property
    @pulumi.getter(name="requestsMCpu")
    def requests_m_cpu(self) -> Optional[pulumi.Input[int]]:
        """
        When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        """
        return pulumi.get(self, "requests_m_cpu")

    @requests_m_cpu.setter
    def requests_m_cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "requests_m_cpu", value)

    @property
    @pulumi.getter(name="requestsMem")
    def requests_mem(self) -> Optional[pulumi.Input[int]]:
        """
        When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        """
        return pulumi.get(self, "requests_mem")

    @requests_mem.setter
    def requests_mem(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "requests_mem", value)

    @property
    @pulumi.getter(name="webContainer")
    def web_container(self) -> Optional[pulumi.Input[str]]:
        """
        The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        return pulumi.get(self, "web_container")

    @web_container.setter
    def web_container(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "web_container", value)


@pulumi.input_type
class _K8sApplicationState:
    def __init__(__self__, *,
                 application_descriotion: Optional[pulumi.Input[str]] = None,
                 application_name: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 command: Optional[pulumi.Input[str]] = None,
                 command_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 edas_container_version: Optional[pulumi.Input[str]] = None,
                 envs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 image_url: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_port: Optional[pulumi.Input[int]] = None,
                 internet_slb_protocol: Optional[pulumi.Input[str]] = None,
                 internet_target_port: Optional[pulumi.Input[int]] = None,
                 jdk: Optional[pulumi.Input[str]] = None,
                 limit_m_cpu: Optional[pulumi.Input[int]] = None,
                 limit_mem: Optional[pulumi.Input[int]] = None,
                 liveness: Optional[pulumi.Input[str]] = None,
                 local_volume: Optional[pulumi.Input[str]] = None,
                 logical_region_id: Optional[pulumi.Input[str]] = None,
                 mount_descs: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 nas_id: Optional[pulumi.Input[str]] = None,
                 package_type: Optional[pulumi.Input[str]] = None,
                 package_url: Optional[pulumi.Input[str]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 post_start: Optional[pulumi.Input[str]] = None,
                 pre_stop: Optional[pulumi.Input[str]] = None,
                 readiness: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[int]] = None,
                 requests_m_cpu: Optional[pulumi.Input[int]] = None,
                 requests_mem: Optional[pulumi.Input[int]] = None,
                 web_container: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering K8sApplication resources.
        :param pulumi.Input[str] application_descriotion: The description of the application
        :param pulumi.Input[str] application_name: The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        :param pulumi.Input[str] cluster_id: The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        :param pulumi.Input[str] command: The set command, if set, will replace the startup command in the mirror when the mirror is started.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command_args: Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        :param pulumi.Input[str] edas_container_version: EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] envs: Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        :param pulumi.Input[str] image_url: Mirror address. When the package_type is set to 'Image', this parameter item is required.
        :param pulumi.Input[str] internet_slb_id: Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_slb_port: The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] internet_slb_protocol: The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_target_port: The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] jdk: The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        :param pulumi.Input[int] limit_m_cpu: The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        :param pulumi.Input[int] limit_mem: The memory limit of the application instance during application operation, unit: M.
        :param pulumi.Input[str] liveness: Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        :param pulumi.Input[str] local_volume: The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        :param pulumi.Input[str] logical_region_id: The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        :param pulumi.Input[str] mount_descs: Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        :param pulumi.Input[str] namespace: The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        :param pulumi.Input[str] nas_id: The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        :param pulumi.Input[str] package_type: Application package type. Optional parameter values include: FatJar, WAR and Image.
        :param pulumi.Input[str] package_url: The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        :param pulumi.Input[str] package_version: The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        :param pulumi.Input[str] post_start: Execute script after startup
        :param pulumi.Input[str] pre_stop: Execute script before stopping
        :param pulumi.Input[str] readiness: Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        :param pulumi.Input[int] replicas: Number of application instances.
        :param pulumi.Input[int] requests_m_cpu: When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        :param pulumi.Input[int] requests_mem: When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        :param pulumi.Input[str] web_container: The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        if application_descriotion is not None:
            pulumi.set(__self__, "application_descriotion", application_descriotion)
        if application_name is not None:
            pulumi.set(__self__, "application_name", application_name)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if command is not None:
            pulumi.set(__self__, "command", command)
        if command_args is not None:
            pulumi.set(__self__, "command_args", command_args)
        if edas_container_version is not None:
            pulumi.set(__self__, "edas_container_version", edas_container_version)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if internet_slb_id is not None:
            warnings.warn("""Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_id is deprecated: Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_id is not None:
            pulumi.set(__self__, "internet_slb_id", internet_slb_id)
        if internet_slb_port is not None:
            warnings.warn("""Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_port is deprecated: Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_port is not None:
            pulumi.set(__self__, "internet_slb_port", internet_slb_port)
        if internet_slb_protocol is not None:
            warnings.warn("""Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_slb_protocol is deprecated: Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_slb_protocol is not None:
            pulumi.set(__self__, "internet_slb_protocol", internet_slb_protocol)
        if internet_target_port is not None:
            warnings.warn("""Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""", DeprecationWarning)
            pulumi.log.warn("""internet_target_port is deprecated: Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
        if internet_target_port is not None:
            pulumi.set(__self__, "internet_target_port", internet_target_port)
        if jdk is not None:
            pulumi.set(__self__, "jdk", jdk)
        if limit_m_cpu is not None:
            pulumi.set(__self__, "limit_m_cpu", limit_m_cpu)
        if limit_mem is not None:
            pulumi.set(__self__, "limit_mem", limit_mem)
        if liveness is not None:
            pulumi.set(__self__, "liveness", liveness)
        if local_volume is not None:
            pulumi.set(__self__, "local_volume", local_volume)
        if logical_region_id is not None:
            pulumi.set(__self__, "logical_region_id", logical_region_id)
        if mount_descs is not None:
            pulumi.set(__self__, "mount_descs", mount_descs)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if nas_id is not None:
            pulumi.set(__self__, "nas_id", nas_id)
        if package_type is not None:
            pulumi.set(__self__, "package_type", package_type)
        if package_url is not None:
            pulumi.set(__self__, "package_url", package_url)
        if package_version is not None:
            pulumi.set(__self__, "package_version", package_version)
        if post_start is not None:
            pulumi.set(__self__, "post_start", post_start)
        if pre_stop is not None:
            pulumi.set(__self__, "pre_stop", pre_stop)
        if readiness is not None:
            pulumi.set(__self__, "readiness", readiness)
        if replicas is not None:
            pulumi.set(__self__, "replicas", replicas)
        if requests_m_cpu is not None:
            pulumi.set(__self__, "requests_m_cpu", requests_m_cpu)
        if requests_mem is not None:
            pulumi.set(__self__, "requests_mem", requests_mem)
        if web_container is not None:
            pulumi.set(__self__, "web_container", web_container)

    @property
    @pulumi.getter(name="applicationDescriotion")
    def application_descriotion(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the application
        """
        return pulumi.get(self, "application_descriotion")

    @application_descriotion.setter
    def application_descriotion(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_descriotion", value)

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        """
        return pulumi.get(self, "application_name")

    @application_name.setter
    def application_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_name", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def command(self) -> Optional[pulumi.Input[str]]:
        """
        The set command, if set, will replace the startup command in the mirror when the mirror is started.
        """
        return pulumi.get(self, "command")

    @command.setter
    def command(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "command", value)

    @property
    @pulumi.getter(name="commandArgs")
    def command_args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        """
        return pulumi.get(self, "command_args")

    @command_args.setter
    def command_args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "command_args", value)

    @property
    @pulumi.getter(name="edasContainerVersion")
    def edas_container_version(self) -> Optional[pulumi.Input[str]]:
        """
        EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        """
        return pulumi.get(self, "edas_container_version")

    @edas_container_version.setter
    def edas_container_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edas_container_version", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        """
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[str]]:
        """
        Mirror address. When the package_type is set to 'Image', this parameter item is required.
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter(name="internetSlbId")
    @_utilities.deprecated("""Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_id")

    @internet_slb_id.setter
    def internet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_id", value)

    @property
    @pulumi.getter(name="internetSlbPort")
    @_utilities.deprecated("""Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_port(self) -> Optional[pulumi.Input[int]]:
        """
        The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_port")

    @internet_slb_port.setter
    def internet_slb_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "internet_slb_port", value)

    @property
    @pulumi.getter(name="internetSlbProtocol")
    @_utilities.deprecated("""Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_protocol")

    @internet_slb_protocol.setter
    def internet_slb_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_protocol", value)

    @property
    @pulumi.getter(name="internetTargetPort")
    @_utilities.deprecated("""Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_target_port(self) -> Optional[pulumi.Input[int]]:
        """
        The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_target_port")

    @internet_target_port.setter
    def internet_target_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "internet_target_port", value)

    @property
    @pulumi.getter
    def jdk(self) -> Optional[pulumi.Input[str]]:
        """
        The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        """
        return pulumi.get(self, "jdk")

    @jdk.setter
    def jdk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jdk", value)

    @property
    @pulumi.getter(name="limitMCpu")
    def limit_m_cpu(self) -> Optional[pulumi.Input[int]]:
        """
        The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        """
        return pulumi.get(self, "limit_m_cpu")

    @limit_m_cpu.setter
    def limit_m_cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_m_cpu", value)

    @property
    @pulumi.getter(name="limitMem")
    def limit_mem(self) -> Optional[pulumi.Input[int]]:
        """
        The memory limit of the application instance during application operation, unit: M.
        """
        return pulumi.get(self, "limit_mem")

    @limit_mem.setter
    def limit_mem(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "limit_mem", value)

    @property
    @pulumi.getter
    def liveness(self) -> Optional[pulumi.Input[str]]:
        """
        Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        """
        return pulumi.get(self, "liveness")

    @liveness.setter
    def liveness(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "liveness", value)

    @property
    @pulumi.getter(name="localVolume")
    def local_volume(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        """
        return pulumi.get(self, "local_volume")

    @local_volume.setter
    def local_volume(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_volume", value)

    @property
    @pulumi.getter(name="logicalRegionId")
    def logical_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        """
        return pulumi.get(self, "logical_region_id")

    @logical_region_id.setter
    def logical_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logical_region_id", value)

    @property
    @pulumi.getter(name="mountDescs")
    def mount_descs(self) -> Optional[pulumi.Input[str]]:
        """
        Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        """
        return pulumi.get(self, "mount_descs")

    @mount_descs.setter
    def mount_descs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mount_descs", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="nasId")
    def nas_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        """
        return pulumi.get(self, "nas_id")

    @nas_id.setter
    def nas_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nas_id", value)

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> Optional[pulumi.Input[str]]:
        """
        Application package type. Optional parameter values include: FatJar, WAR and Image.
        """
        return pulumi.get(self, "package_type")

    @package_type.setter
    def package_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_type", value)

    @property
    @pulumi.getter(name="packageUrl")
    def package_url(self) -> Optional[pulumi.Input[str]]:
        """
        The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        """
        return pulumi.get(self, "package_url")

    @package_url.setter
    def package_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_url", value)

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        """
        return pulumi.get(self, "package_version")

    @package_version.setter
    def package_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_version", value)

    @property
    @pulumi.getter(name="postStart")
    def post_start(self) -> Optional[pulumi.Input[str]]:
        """
        Execute script after startup
        """
        return pulumi.get(self, "post_start")

    @post_start.setter
    def post_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "post_start", value)

    @property
    @pulumi.getter(name="preStop")
    def pre_stop(self) -> Optional[pulumi.Input[str]]:
        """
        Execute script before stopping
        """
        return pulumi.get(self, "pre_stop")

    @pre_stop.setter
    def pre_stop(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pre_stop", value)

    @property
    @pulumi.getter
    def readiness(self) -> Optional[pulumi.Input[str]]:
        """
        Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        """
        return pulumi.get(self, "readiness")

    @readiness.setter
    def readiness(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "readiness", value)

    @property
    @pulumi.getter
    def replicas(self) -> Optional[pulumi.Input[int]]:
        """
        Number of application instances.
        """
        return pulumi.get(self, "replicas")

    @replicas.setter
    def replicas(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "replicas", value)

    @property
    @pulumi.getter(name="requestsMCpu")
    def requests_m_cpu(self) -> Optional[pulumi.Input[int]]:
        """
        When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        """
        return pulumi.get(self, "requests_m_cpu")

    @requests_m_cpu.setter
    def requests_m_cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "requests_m_cpu", value)

    @property
    @pulumi.getter(name="requestsMem")
    def requests_mem(self) -> Optional[pulumi.Input[int]]:
        """
        When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        """
        return pulumi.get(self, "requests_mem")

    @requests_mem.setter
    def requests_mem(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "requests_mem", value)

    @property
    @pulumi.getter(name="webContainer")
    def web_container(self) -> Optional[pulumi.Input[str]]:
        """
        The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        return pulumi.get(self, "web_container")

    @web_container.setter
    def web_container(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "web_container", value)


class K8sApplication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_descriotion: Optional[pulumi.Input[str]] = None,
                 application_name: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 command: Optional[pulumi.Input[str]] = None,
                 command_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 edas_container_version: Optional[pulumi.Input[str]] = None,
                 envs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 image_url: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_port: Optional[pulumi.Input[int]] = None,
                 internet_slb_protocol: Optional[pulumi.Input[str]] = None,
                 internet_target_port: Optional[pulumi.Input[int]] = None,
                 jdk: Optional[pulumi.Input[str]] = None,
                 limit_m_cpu: Optional[pulumi.Input[int]] = None,
                 limit_mem: Optional[pulumi.Input[int]] = None,
                 liveness: Optional[pulumi.Input[str]] = None,
                 local_volume: Optional[pulumi.Input[str]] = None,
                 logical_region_id: Optional[pulumi.Input[str]] = None,
                 mount_descs: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 nas_id: Optional[pulumi.Input[str]] = None,
                 package_type: Optional[pulumi.Input[str]] = None,
                 package_url: Optional[pulumi.Input[str]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 post_start: Optional[pulumi.Input[str]] = None,
                 pre_stop: Optional[pulumi.Input[str]] = None,
                 readiness: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[int]] = None,
                 requests_m_cpu: Optional[pulumi.Input[int]] = None,
                 requests_mem: Optional[pulumi.Input[int]] = None,
                 web_container: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create an EDAS k8s application.For information about EDAS K8s Application and how to use it, see [What is EDAS K8s Application](https://www.alibabacloud.com/help/en/edas/developer-reference/api-edas-2017-08-01-insertk8sapplication).

        > **NOTE:** Available since v1.105.0.

        ## Import

        EDAS k8s application can be imported as below, e.g.

        ```sh
        $ pulumi import alicloud:edas/k8sApplication:K8sApplication new_k8s_application application_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_descriotion: The description of the application
        :param pulumi.Input[str] application_name: The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        :param pulumi.Input[str] cluster_id: The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        :param pulumi.Input[str] command: The set command, if set, will replace the startup command in the mirror when the mirror is started.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command_args: Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        :param pulumi.Input[str] edas_container_version: EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] envs: Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        :param pulumi.Input[str] image_url: Mirror address. When the package_type is set to 'Image', this parameter item is required.
        :param pulumi.Input[str] internet_slb_id: Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_slb_port: The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] internet_slb_protocol: The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_target_port: The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] jdk: The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        :param pulumi.Input[int] limit_m_cpu: The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        :param pulumi.Input[int] limit_mem: The memory limit of the application instance during application operation, unit: M.
        :param pulumi.Input[str] liveness: Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        :param pulumi.Input[str] local_volume: The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        :param pulumi.Input[str] logical_region_id: The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        :param pulumi.Input[str] mount_descs: Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        :param pulumi.Input[str] namespace: The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        :param pulumi.Input[str] nas_id: The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        :param pulumi.Input[str] package_type: Application package type. Optional parameter values include: FatJar, WAR and Image.
        :param pulumi.Input[str] package_url: The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        :param pulumi.Input[str] package_version: The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        :param pulumi.Input[str] post_start: Execute script after startup
        :param pulumi.Input[str] pre_stop: Execute script before stopping
        :param pulumi.Input[str] readiness: Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        :param pulumi.Input[int] replicas: Number of application instances.
        :param pulumi.Input[int] requests_m_cpu: When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        :param pulumi.Input[int] requests_mem: When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        :param pulumi.Input[str] web_container: The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: K8sApplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create an EDAS k8s application.For information about EDAS K8s Application and how to use it, see [What is EDAS K8s Application](https://www.alibabacloud.com/help/en/edas/developer-reference/api-edas-2017-08-01-insertk8sapplication).

        > **NOTE:** Available since v1.105.0.

        ## Import

        EDAS k8s application can be imported as below, e.g.

        ```sh
        $ pulumi import alicloud:edas/k8sApplication:K8sApplication new_k8s_application application_id
        ```

        :param str resource_name: The name of the resource.
        :param K8sApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(K8sApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_descriotion: Optional[pulumi.Input[str]] = None,
                 application_name: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 command: Optional[pulumi.Input[str]] = None,
                 command_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 edas_container_version: Optional[pulumi.Input[str]] = None,
                 envs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 image_url: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_port: Optional[pulumi.Input[int]] = None,
                 internet_slb_protocol: Optional[pulumi.Input[str]] = None,
                 internet_target_port: Optional[pulumi.Input[int]] = None,
                 jdk: Optional[pulumi.Input[str]] = None,
                 limit_m_cpu: Optional[pulumi.Input[int]] = None,
                 limit_mem: Optional[pulumi.Input[int]] = None,
                 liveness: Optional[pulumi.Input[str]] = None,
                 local_volume: Optional[pulumi.Input[str]] = None,
                 logical_region_id: Optional[pulumi.Input[str]] = None,
                 mount_descs: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 nas_id: Optional[pulumi.Input[str]] = None,
                 package_type: Optional[pulumi.Input[str]] = None,
                 package_url: Optional[pulumi.Input[str]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 post_start: Optional[pulumi.Input[str]] = None,
                 pre_stop: Optional[pulumi.Input[str]] = None,
                 readiness: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[int]] = None,
                 requests_m_cpu: Optional[pulumi.Input[int]] = None,
                 requests_mem: Optional[pulumi.Input[int]] = None,
                 web_container: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = K8sApplicationArgs.__new__(K8sApplicationArgs)

            __props__.__dict__["application_descriotion"] = application_descriotion
            if application_name is None and not opts.urn:
                raise TypeError("Missing required property 'application_name'")
            __props__.__dict__["application_name"] = application_name
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["command"] = command
            __props__.__dict__["command_args"] = command_args
            __props__.__dict__["edas_container_version"] = edas_container_version
            __props__.__dict__["envs"] = envs
            __props__.__dict__["image_url"] = image_url
            __props__.__dict__["internet_slb_id"] = internet_slb_id
            __props__.__dict__["internet_slb_port"] = internet_slb_port
            __props__.__dict__["internet_slb_protocol"] = internet_slb_protocol
            __props__.__dict__["internet_target_port"] = internet_target_port
            __props__.__dict__["jdk"] = jdk
            __props__.__dict__["limit_m_cpu"] = limit_m_cpu
            __props__.__dict__["limit_mem"] = limit_mem
            __props__.__dict__["liveness"] = liveness
            __props__.__dict__["local_volume"] = local_volume
            __props__.__dict__["logical_region_id"] = logical_region_id
            __props__.__dict__["mount_descs"] = mount_descs
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["nas_id"] = nas_id
            __props__.__dict__["package_type"] = package_type
            __props__.__dict__["package_url"] = package_url
            __props__.__dict__["package_version"] = package_version
            __props__.__dict__["post_start"] = post_start
            __props__.__dict__["pre_stop"] = pre_stop
            __props__.__dict__["readiness"] = readiness
            __props__.__dict__["replicas"] = replicas
            __props__.__dict__["requests_m_cpu"] = requests_m_cpu
            __props__.__dict__["requests_mem"] = requests_mem
            __props__.__dict__["web_container"] = web_container
        super(K8sApplication, __self__).__init__(
            'alicloud:edas/k8sApplication:K8sApplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_descriotion: Optional[pulumi.Input[str]] = None,
            application_name: Optional[pulumi.Input[str]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            command: Optional[pulumi.Input[str]] = None,
            command_args: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            edas_container_version: Optional[pulumi.Input[str]] = None,
            envs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            image_url: Optional[pulumi.Input[str]] = None,
            internet_slb_id: Optional[pulumi.Input[str]] = None,
            internet_slb_port: Optional[pulumi.Input[int]] = None,
            internet_slb_protocol: Optional[pulumi.Input[str]] = None,
            internet_target_port: Optional[pulumi.Input[int]] = None,
            jdk: Optional[pulumi.Input[str]] = None,
            limit_m_cpu: Optional[pulumi.Input[int]] = None,
            limit_mem: Optional[pulumi.Input[int]] = None,
            liveness: Optional[pulumi.Input[str]] = None,
            local_volume: Optional[pulumi.Input[str]] = None,
            logical_region_id: Optional[pulumi.Input[str]] = None,
            mount_descs: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            nas_id: Optional[pulumi.Input[str]] = None,
            package_type: Optional[pulumi.Input[str]] = None,
            package_url: Optional[pulumi.Input[str]] = None,
            package_version: Optional[pulumi.Input[str]] = None,
            post_start: Optional[pulumi.Input[str]] = None,
            pre_stop: Optional[pulumi.Input[str]] = None,
            readiness: Optional[pulumi.Input[str]] = None,
            replicas: Optional[pulumi.Input[int]] = None,
            requests_m_cpu: Optional[pulumi.Input[int]] = None,
            requests_mem: Optional[pulumi.Input[int]] = None,
            web_container: Optional[pulumi.Input[str]] = None) -> 'K8sApplication':
        """
        Get an existing K8sApplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_descriotion: The description of the application
        :param pulumi.Input[str] application_name: The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        :param pulumi.Input[str] cluster_id: The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        :param pulumi.Input[str] command: The set command, if set, will replace the startup command in the mirror when the mirror is started.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] command_args: Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        :param pulumi.Input[str] edas_container_version: EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] envs: Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        :param pulumi.Input[str] image_url: Mirror address. When the package_type is set to 'Image', this parameter item is required.
        :param pulumi.Input[str] internet_slb_id: Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_slb_port: The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] internet_slb_protocol: The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[int] internet_target_port: The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
               It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        :param pulumi.Input[str] jdk: The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        :param pulumi.Input[int] limit_m_cpu: The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        :param pulumi.Input[int] limit_mem: The memory limit of the application instance during application operation, unit: M.
        :param pulumi.Input[str] liveness: Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        :param pulumi.Input[str] local_volume: The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        :param pulumi.Input[str] logical_region_id: The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        :param pulumi.Input[str] mount_descs: Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        :param pulumi.Input[str] namespace: The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        :param pulumi.Input[str] nas_id: The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        :param pulumi.Input[str] package_type: Application package type. Optional parameter values include: FatJar, WAR and Image.
        :param pulumi.Input[str] package_url: The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        :param pulumi.Input[str] package_version: The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        :param pulumi.Input[str] post_start: Execute script after startup
        :param pulumi.Input[str] pre_stop: Execute script before stopping
        :param pulumi.Input[str] readiness: Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        :param pulumi.Input[int] replicas: Number of application instances.
        :param pulumi.Input[int] requests_m_cpu: When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        :param pulumi.Input[int] requests_mem: When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        :param pulumi.Input[str] web_container: The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _K8sApplicationState.__new__(_K8sApplicationState)

        __props__.__dict__["application_descriotion"] = application_descriotion
        __props__.__dict__["application_name"] = application_name
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["command"] = command
        __props__.__dict__["command_args"] = command_args
        __props__.__dict__["edas_container_version"] = edas_container_version
        __props__.__dict__["envs"] = envs
        __props__.__dict__["image_url"] = image_url
        __props__.__dict__["internet_slb_id"] = internet_slb_id
        __props__.__dict__["internet_slb_port"] = internet_slb_port
        __props__.__dict__["internet_slb_protocol"] = internet_slb_protocol
        __props__.__dict__["internet_target_port"] = internet_target_port
        __props__.__dict__["jdk"] = jdk
        __props__.__dict__["limit_m_cpu"] = limit_m_cpu
        __props__.__dict__["limit_mem"] = limit_mem
        __props__.__dict__["liveness"] = liveness
        __props__.__dict__["local_volume"] = local_volume
        __props__.__dict__["logical_region_id"] = logical_region_id
        __props__.__dict__["mount_descs"] = mount_descs
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["nas_id"] = nas_id
        __props__.__dict__["package_type"] = package_type
        __props__.__dict__["package_url"] = package_url
        __props__.__dict__["package_version"] = package_version
        __props__.__dict__["post_start"] = post_start
        __props__.__dict__["pre_stop"] = pre_stop
        __props__.__dict__["readiness"] = readiness
        __props__.__dict__["replicas"] = replicas
        __props__.__dict__["requests_m_cpu"] = requests_m_cpu
        __props__.__dict__["requests_mem"] = requests_mem
        __props__.__dict__["web_container"] = web_container
        return K8sApplication(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationDescriotion")
    def application_descriotion(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the application
        """
        return pulumi.get(self, "application_descriotion")

    @property
    @pulumi.getter(name="applicationName")
    def application_name(self) -> pulumi.Output[str]:
        """
        The name of the application you want to create. Must start with character,supports numbers, letters and dashes (-), supports up to 36 characters
        """
        return pulumi.get(self, "application_name")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        The ID of the alicloud container service kubernetes cluster that you want to import to. You can call the ListCluster operation to query.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def command(self) -> pulumi.Output[Optional[str]]:
        """
        The set command, if set, will replace the startup command in the mirror when the mirror is started.
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter(name="commandArgs")
    def command_args(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Used in combination with the command, the parameter of the command is a JsonArray string in the format: `[{"argument":"-c"},{"argument":"test"}]`. Among them, -c and test are two parameters that need to be set.
        """
        return pulumi.get(self, "command_args")

    @property
    @pulumi.getter(name="edasContainerVersion")
    def edas_container_version(self) -> pulumi.Output[Optional[str]]:
        """
        EDAS-Container version that the deployed package depends on. Image does not support this parameter.
        """
        return pulumi.get(self, "edas_container_version")

    @property
    @pulumi.getter
    def envs(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Deployment environment variables, the format must conform to the JSON object array, such as: `{"name":"x","value":"y"},{"name":"x2","value":"y2"}`, If you want to cancel the configuration, you need to set an empty JSON array "" to indicate no configuration.
        """
        return pulumi.get(self, "envs")

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> pulumi.Output[Optional[str]]:
        """
        Mirror address. When the package_type is set to 'Image', this parameter item is required.
        """
        return pulumi.get(self, "image_url")

    @property
    @pulumi.getter(name="internetSlbId")
    @_utilities.deprecated("""Field 'internet_slb_id' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_id(self) -> pulumi.Output[Optional[str]]:
        """
        Public network SLB ID. If not configured, EDAS will automatically purchase a new SLB for the user.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_id")

    @property
    @pulumi.getter(name="internetSlbPort")
    @_utilities.deprecated("""Field 'internet_slb_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_port(self) -> pulumi.Output[Optional[int]]:
        """
        The public network SLB front-end port, range 1~65535. It has been deprecated and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_port")

    @property
    @pulumi.getter(name="internetSlbProtocol")
    @_utilities.deprecated("""Field 'internet_slb_protocol' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_slb_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        The public network SLB protocol supports TCP, HTTP and HTTPS protocols. It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_slb_protocol")

    @property
    @pulumi.getter(name="internetTargetPort")
    @_utilities.deprecated("""Field 'internet_target_port' has been deprecated, New Resource 'alicloud_edas_k8s_slb_attachment' replaces it""")
    def internet_target_port(self) -> pulumi.Output[Optional[int]]:
        """
        The private SLB back-end port, is also the service port of the application, ranging from 1 to 65535.
        It has been deprecated, and new resource 'alicloud_edas_k8s_slb_attachment' replaces it.
        """
        return pulumi.get(self, "internet_target_port")

    @property
    @pulumi.getter
    def jdk(self) -> pulumi.Output[Optional[str]]:
        """
        The JDK version that the deployed package depends on. The optional parameter values are Open JDK 7 and Open JDK 8. Image does not support this parameter.
        """
        return pulumi.get(self, "jdk")

    @property
    @pulumi.getter(name="limitMCpu")
    def limit_m_cpu(self) -> pulumi.Output[Optional[int]]:
        """
        The CPU quota of the application instance during application operation. Unit: Number of millcores, set to 0 means unlimited, similar to request_cpu.
        """
        return pulumi.get(self, "limit_m_cpu")

    @property
    @pulumi.getter(name="limitMem")
    def limit_mem(self) -> pulumi.Output[Optional[int]]:
        """
        The memory limit of the application instance during application operation, unit: M.
        """
        return pulumi.get(self, "limit_mem")

    @property
    @pulumi.getter
    def liveness(self) -> pulumi.Output[Optional[str]]:
        """
        Container survival status monitoring, format such as: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1,"tcpSocket":{"host":"", "port":8080} }`.
        """
        return pulumi.get(self, "liveness")

    @property
    @pulumi.getter(name="localVolume")
    def local_volume(self) -> pulumi.Output[Optional[str]]:
        """
        The configuration of the host file mounted to the container. For example: `[{"type":"","nodePath":"/localfiles","mountPath":"/app/files"},{"type":"Directory","nodePath":"/mnt", "mountPath":"/app/storage"}]`. Among them, nodePath is the host path; mountPath is the path in the container; type is the mount type.
        """
        return pulumi.get(self, "local_volume")

    @property
    @pulumi.getter(name="logicalRegionId")
    def logical_region_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID corresponding to the EDAS namespace, the non-default namespace must be filled in.
        """
        return pulumi.get(self, "logical_region_id")

    @property
    @pulumi.getter(name="mountDescs")
    def mount_descs(self) -> pulumi.Output[Optional[str]]:
        """
        Mount configuration description, as a serialized JSON. For example: `[{"nasPath": "/k8s","mountPath": "/mnt"},{"nasPath": "/files","mountPath": "/app/files"}]`. Among them, nasPath refers to the file storage path; mountPath refers to the path mounted in the container.
        """
        return pulumi.get(self, "mount_descs")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace of the K8s cluster, it will determine which K8s namespace your application is deployed in. The default is 'default'.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="nasId")
    def nas_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the mounted NAS must be in the same region as the cluster. It must have an available mount point creation quota, or its mount point must be on a switch in the VPC. If it is not filled in and the mountDescs field exists, a NAS will be automatically purchased and mounted on the switch in the VPC by default.
        """
        return pulumi.get(self, "nas_id")

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> pulumi.Output[Optional[str]]:
        """
        Application package type. Optional parameter values include: FatJar, WAR and Image.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter(name="packageUrl")
    def package_url(self) -> pulumi.Output[Optional[str]]:
        """
        The url of the package to deploy.Applications deployed through FatJar or WAR packages need to configure it.
        """
        return pulumi.get(self, "package_url")

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> pulumi.Output[str]:
        """
        The version number of the deployment package. WAR and FatJar types are required. Please customize its meaning.
        """
        return pulumi.get(self, "package_version")

    @property
    @pulumi.getter(name="postStart")
    def post_start(self) -> pulumi.Output[Optional[str]]:
        """
        Execute script after startup
        """
        return pulumi.get(self, "post_start")

    @property
    @pulumi.getter(name="preStop")
    def pre_stop(self) -> pulumi.Output[Optional[str]]:
        """
        Execute script before stopping
        """
        return pulumi.get(self, "pre_stop")

    @property
    @pulumi.getter
    def readiness(self) -> pulumi.Output[Optional[str]]:
        """
        Container service status check. If the check fails, the traffic passing through K8s Service will not be transferred to the container. The format is: `{"failureThreshold": 3,"initialDelaySeconds": 5,"successThreshold": 1,"timeoutSeconds": 1, "httpGet": {"path": "/consumer","port": 8080,"scheme": "HTTP","httpHeaders": [{"name": "test","value": "testvalue"} ]}}`.
        """
        return pulumi.get(self, "readiness")

    @property
    @pulumi.getter
    def replicas(self) -> pulumi.Output[Optional[int]]:
        """
        Number of application instances.
        """
        return pulumi.get(self, "replicas")

    @property
    @pulumi.getter(name="requestsMCpu")
    def requests_m_cpu(self) -> pulumi.Output[Optional[int]]:
        """
        When the application is created, the CPU quota of the application instance, unit: number of millcores, similar to request_cpu
        """
        return pulumi.get(self, "requests_m_cpu")

    @property
    @pulumi.getter(name="requestsMem")
    def requests_mem(self) -> pulumi.Output[Optional[int]]:
        """
        When the application is created, the memory limit of the application instance, unit: M. When set to 0, it means unlimited.
        """
        return pulumi.get(self, "requests_mem")

    @property
    @pulumi.getter(name="webContainer")
    def web_container(self) -> pulumi.Output[Optional[str]]:
        """
        The Tomcat version that the deployment package depends on. Applicable to Spring Cloud and Dubbo applications deployed through WAR packages. Image does not support this parameter.
        """
        return pulumi.get(self, "web_container")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NetworkRuleArgs', 'NetworkRule']

@pulumi.input_type
class NetworkRuleArgs:
    def __init__(__self__, *,
                 source_private_ips: pulumi.Input[Sequence[pulumi.Input[str]]],
                 description: Optional[pulumi.Input[str]] = None,
                 network_rule_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NetworkRule resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_private_ips: Allowed private network addresses.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] network_rule_name: Network Rule Name.
        """
        pulumi.set(__self__, "source_private_ips", source_private_ips)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if network_rule_name is not None:
            pulumi.set(__self__, "network_rule_name", network_rule_name)

    @property
    @pulumi.getter(name="sourcePrivateIps")
    def source_private_ips(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Allowed private network addresses.
        """
        return pulumi.get(self, "source_private_ips")

    @source_private_ips.setter
    def source_private_ips(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "source_private_ips", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="networkRuleName")
    def network_rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        Network Rule Name.
        """
        return pulumi.get(self, "network_rule_name")

    @network_rule_name.setter
    def network_rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_rule_name", value)


@pulumi.input_type
class _NetworkRuleState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 network_rule_name: Optional[pulumi.Input[str]] = None,
                 source_private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering NetworkRule resources.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] network_rule_name: Network Rule Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_private_ips: Allowed private network addresses.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if network_rule_name is not None:
            pulumi.set(__self__, "network_rule_name", network_rule_name)
        if source_private_ips is not None:
            pulumi.set(__self__, "source_private_ips", source_private_ips)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="networkRuleName")
    def network_rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        Network Rule Name.
        """
        return pulumi.get(self, "network_rule_name")

    @network_rule_name.setter
    def network_rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_rule_name", value)

    @property
    @pulumi.getter(name="sourcePrivateIps")
    def source_private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Allowed private network addresses.
        """
        return pulumi.get(self, "source_private_ips")

    @source_private_ips.setter
    def source_private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "source_private_ips", value)


class NetworkRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 network_rule_name: Optional[pulumi.Input[str]] = None,
                 source_private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a KMS Network Rule resource. Network rules that can be bound by Application Access Point's policies.

        For information about KMS Network Rule and how to use it, see [What is Network Rule](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createnetworkrule).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.kms.NetworkRule("default",
            description="example-description",
            source_private_ips=[
                "10.10.10.10/24",
                "192.168.17.13",
                "100.177.24.254",
            ],
            network_rule_name=name)
        ```

        ## Import

        KMS Network Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/networkRule:NetworkRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] network_rule_name: Network Rule Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_private_ips: Allowed private network addresses.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a KMS Network Rule resource. Network rules that can be bound by Application Access Point's policies.

        For information about KMS Network Rule and how to use it, see [What is Network Rule](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createnetworkrule).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.kms.NetworkRule("default",
            description="example-description",
            source_private_ips=[
                "10.10.10.10/24",
                "192.168.17.13",
                "100.177.24.254",
            ],
            network_rule_name=name)
        ```

        ## Import

        KMS Network Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/networkRule:NetworkRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NetworkRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 network_rule_name: Optional[pulumi.Input[str]] = None,
                 source_private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkRuleArgs.__new__(NetworkRuleArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["network_rule_name"] = network_rule_name
            if source_private_ips is None and not opts.urn:
                raise TypeError("Missing required property 'source_private_ips'")
            __props__.__dict__["source_private_ips"] = source_private_ips
        super(NetworkRule, __self__).__init__(
            'alicloud:kms/networkRule:NetworkRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            network_rule_name: Optional[pulumi.Input[str]] = None,
            source_private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'NetworkRule':
        """
        Get an existing NetworkRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] network_rule_name: Network Rule Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_private_ips: Allowed private network addresses.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkRuleState.__new__(_NetworkRuleState)

        __props__.__dict__["description"] = description
        __props__.__dict__["network_rule_name"] = network_rule_name
        __props__.__dict__["source_private_ips"] = source_private_ips
        return NetworkRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="networkRuleName")
    def network_rule_name(self) -> pulumi.Output[str]:
        """
        Network Rule Name.
        """
        return pulumi.get(self, "network_rule_name")

    @property
    @pulumi.getter(name="sourcePrivateIps")
    def source_private_ips(self) -> pulumi.Output[Sequence[str]]:
        """
        Allowed private network addresses.
        """
        return pulumi.get(self, "source_private_ips")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBaselinesResult',
    'AwaitableGetBaselinesResult',
    'get_baselines',
    'get_baselines_output',
]

@pulumi.output_type
class GetBaselinesResult:
    """
    A collection of values returned by getBaselines.
    """
    def __init__(__self__, baselines=None, id=None, ids=None, name_regex=None, names=None, output_file=None):
        if baselines and not isinstance(baselines, list):
            raise TypeError("Expected argument 'baselines' to be a list")
        pulumi.set(__self__, "baselines", baselines)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def baselines(self) -> Sequence['outputs.GetBaselinesBaselineResult']:
        """
        A list of Baseline Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "baselines")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Baseline IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of name of Baselines.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetBaselinesResult(GetBaselinesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBaselinesResult(
            baselines=self.baselines,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file)


def get_baselines(ids: Optional[Sequence[str]] = None,
                  name_regex: Optional[str] = None,
                  output_file: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBaselinesResult:
    """
    This data source provides Governance Baseline available to the user.[What is Baseline](https://next.api.aliyun.com/document/governance/2021-01-20/CreateAccountFactoryBaseline)

    > **NOTE:** Available since v1.228.0.

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform_example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    item_password_policy = config.get("itemPasswordPolicy")
    if item_password_policy is None:
        item_password_policy = "ACS-BP_ACCOUNT_FACTORY_RAM_USER_PASSWORD_POLICY"
    item_services = config.get("itemServices")
    if item_services is None:
        item_services = "ACS-BP_ACCOUNT_FACTORY_SUBSCRIBE_SERVICES"
    item_ram_security = config.get("itemRamSecurity")
    if item_ram_security is None:
        item_ram_security = "ACS-BP_ACCOUNT_FACTORY_RAM_SECURITY_PREFERENCE"
    default_baseline = alicloud.governance.Baseline("default",
        baseline_items=[{
            "version": "1.0",
            "name": item_password_policy,
            "config": json.dumps({
                "MinimumPasswordLength": 8,
                "RequireLowercaseCharacters": True,
                "RequireUppercaseCharacters": True,
                "RequireNumbers": True,
                "RequireSymbols": True,
                "MaxPasswordAge": 0,
                "HardExpiry": False,
                "PasswordReusePrevention": 0,
                "MaxLoginAttempts": 0,
            }),
        }],
        description=name,
        baseline_name=f"{name}-{default_integer['result']}")
    default = pulumi.Output.all(
        id=default_baseline.id,
        baseline_name=default_baseline.baseline_name
    ).apply(lambda resolved_outputs: alicloud.governance.get_baselines_output(ids=[resolved_outputs['id']],
        name_regex=resolved_outputs['baseline_name']))

    pulumi.export("alicloudGovernanceBaselineExampleId", default.baselines[0].baseline_id)
    ```


    :param Sequence[str] ids: A list of Baseline IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:governance/getBaselines:getBaselines', __args__, opts=opts, typ=GetBaselinesResult).value

    return AwaitableGetBaselinesResult(
        baselines=pulumi.get(__ret__, 'baselines'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_baselines_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBaselinesResult]:
    """
    This data source provides Governance Baseline available to the user.[What is Baseline](https://next.api.aliyun.com/document/governance/2021-01-20/CreateAccountFactoryBaseline)

    > **NOTE:** Available since v1.228.0.

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform_example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    item_password_policy = config.get("itemPasswordPolicy")
    if item_password_policy is None:
        item_password_policy = "ACS-BP_ACCOUNT_FACTORY_RAM_USER_PASSWORD_POLICY"
    item_services = config.get("itemServices")
    if item_services is None:
        item_services = "ACS-BP_ACCOUNT_FACTORY_SUBSCRIBE_SERVICES"
    item_ram_security = config.get("itemRamSecurity")
    if item_ram_security is None:
        item_ram_security = "ACS-BP_ACCOUNT_FACTORY_RAM_SECURITY_PREFERENCE"
    default_baseline = alicloud.governance.Baseline("default",
        baseline_items=[{
            "version": "1.0",
            "name": item_password_policy,
            "config": json.dumps({
                "MinimumPasswordLength": 8,
                "RequireLowercaseCharacters": True,
                "RequireUppercaseCharacters": True,
                "RequireNumbers": True,
                "RequireSymbols": True,
                "MaxPasswordAge": 0,
                "HardExpiry": False,
                "PasswordReusePrevention": 0,
                "MaxLoginAttempts": 0,
            }),
        }],
        description=name,
        baseline_name=f"{name}-{default_integer['result']}")
    default = pulumi.Output.all(
        id=default_baseline.id,
        baseline_name=default_baseline.baseline_name
    ).apply(lambda resolved_outputs: alicloud.governance.get_baselines_output(ids=[resolved_outputs['id']],
        name_regex=resolved_outputs['baseline_name']))

    pulumi.export("alicloudGovernanceBaselineExampleId", default.baselines[0].baseline_id)
    ```


    :param Sequence[str] ids: A list of Baseline IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:governance/getBaselines:getBaselines', __args__, opts=opts, typ=GetBaselinesResult)
    return __ret__.apply(lambda __response__: GetBaselinesResult(
        baselines=pulumi.get(__response__, 'baselines'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerGroupsResult',
    'AwaitableGetServerGroupsResult',
    'get_server_groups',
    'get_server_groups_output',
]

@pulumi.output_type
class GetServerGroupsResult:
    """
    A collection of values returned by getServerGroups.
    """
    def __init__(__self__, enable_details=None, groups=None, id=None, ids=None, name_regex=None, names=None, output_file=None, resource_group_id=None, server_group_ids=None, server_group_name=None, status=None, tags=None, vpc_id=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if server_group_ids and not isinstance(server_group_ids, list):
            raise TypeError("Expected argument 'server_group_ids' to be a list")
        pulumi.set(__self__, "server_group_ids", server_group_ids)
        if server_group_name and not isinstance(server_group_name, str):
            raise TypeError("Expected argument 'server_group_name' to be a str")
        pulumi.set(__self__, "server_group_name", server_group_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetServerGroupsGroupResult']:
        """
        A list of Alb Server Groups. Each element contains the following attributes:
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Server Group names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="serverGroupIds")
    def server_group_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "server_group_ids")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the resource. Valid values: `Provisioning`, `Available` and `Configuring`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[str]:
        """
        The ID of the VPC that you want to access.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetServerGroupsResult(GetServerGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerGroupsResult(
            enable_details=self.enable_details,
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            server_group_ids=self.server_group_ids,
            server_group_name=self.server_group_name,
            status=self.status,
            tags=self.tags,
            vpc_id=self.vpc_id)


def get_server_groups(enable_details: Optional[bool] = None,
                      ids: Optional[Sequence[str]] = None,
                      name_regex: Optional[str] = None,
                      output_file: Optional[str] = None,
                      resource_group_id: Optional[str] = None,
                      server_group_ids: Optional[Sequence[str]] = None,
                      server_group_name: Optional[str] = None,
                      status: Optional[str] = None,
                      tags: Optional[Mapping[str, str]] = None,
                      vpc_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerGroupsResult:
    """
    This data source provides the Alb Server Groups of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.131.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.alb.get_server_groups()
    pulumi.export("albServerGroupId1", ids.groups[0].id)
    name_regex = alicloud.alb.get_server_groups(name_regex="^my-ServerGroup")
    pulumi.export("albServerGroupId2", name_regex.groups[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Server Group IDs.
    :param str name_regex: A regex string to filter results by Server Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param Sequence[str] server_group_ids: The server group ids.
    :param str server_group_name: The name of the resource.
    :param str status: The status of the resource.
    :param Mapping[str, str] tags: A map of tags assigned to the group.
    :param str vpc_id: The ID of the VPC that you want to access.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['serverGroupIds'] = server_group_ids
    __args__['serverGroupName'] = server_group_name
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:alb/getServerGroups:getServerGroups', __args__, opts=opts, typ=GetServerGroupsResult).value

    return AwaitableGetServerGroupsResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        server_group_ids=pulumi.get(__ret__, 'server_group_ids'),
        server_group_name=pulumi.get(__ret__, 'server_group_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_server_groups_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                             ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                             server_group_ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             server_group_name: Optional[pulumi.Input[Optional[str]]] = None,
                             status: Optional[pulumi.Input[Optional[str]]] = None,
                             tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                             vpc_id: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServerGroupsResult]:
    """
    This data source provides the Alb Server Groups of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.131.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.alb.get_server_groups()
    pulumi.export("albServerGroupId1", ids.groups[0].id)
    name_regex = alicloud.alb.get_server_groups(name_regex="^my-ServerGroup")
    pulumi.export("albServerGroupId2", name_regex.groups[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Server Group IDs.
    :param str name_regex: A regex string to filter results by Server Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param Sequence[str] server_group_ids: The server group ids.
    :param str server_group_name: The name of the resource.
    :param str status: The status of the resource.
    :param Mapping[str, str] tags: A map of tags assigned to the group.
    :param str vpc_id: The ID of the VPC that you want to access.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['serverGroupIds'] = server_group_ids
    __args__['serverGroupName'] = server_group_name
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:alb/getServerGroups:getServerGroups', __args__, opts=opts, typ=GetServerGroupsResult)
    return __ret__.apply(lambda __response__: GetServerGroupsResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        server_group_ids=pulumi.get(__response__, 'server_group_ids'),
        server_group_name=pulumi.get(__response__, 'server_group_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpdsResult',
    'AwaitableGetVpdsResult',
    'get_vpds',
    'get_vpds_output',
]

@pulumi.output_type
class GetVpdsResult:
    """
    A collection of values returned by getVpds.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None, resource_group_id=None, status=None, vpd_id=None, vpd_name=None, vpds=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if vpd_id and not isinstance(vpd_id, str):
            raise TypeError("Expected argument 'vpd_id' to be a str")
        pulumi.set(__self__, "vpd_id", vpd_id)
        if vpd_name and not isinstance(vpd_name, str):
            raise TypeError("Expected argument 'vpd_name' to be a str")
        pulumi.set(__self__, "vpd_name", vpd_name)
        if vpds and not isinstance(vpds, list):
            raise TypeError("Expected argument 'vpds' to be a list")
        pulumi.set(__self__, "vpds", vpds)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Vpd IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of name of Vpds.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        """
        Resource group id
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The Vpd status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpdId")
    def vpd_id(self) -> Optional[str]:
        """
        The id of the vpd.
        """
        return pulumi.get(self, "vpd_id")

    @property
    @pulumi.getter(name="vpdName")
    def vpd_name(self) -> Optional[str]:
        """
        The Name of the VPD.
        """
        return pulumi.get(self, "vpd_name")

    @property
    @pulumi.getter
    def vpds(self) -> Sequence['outputs.GetVpdsVpdResult']:
        """
        A list of Vpd Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "vpds")


class AwaitableGetVpdsResult(GetVpdsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpdsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            resource_group_id=self.resource_group_id,
            status=self.status,
            vpd_id=self.vpd_id,
            vpd_name=self.vpd_name,
            vpds=self.vpds)


def get_vpds(enable_details: Optional[bool] = None,
             ids: Optional[Sequence[str]] = None,
             name_regex: Optional[str] = None,
             output_file: Optional[str] = None,
             page_number: Optional[int] = None,
             page_size: Optional[int] = None,
             resource_group_id: Optional[str] = None,
             status: Optional[str] = None,
             vpd_id: Optional[str] = None,
             vpd_name: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpdsResult:
    """
    This data source provides Eflo Vpd available to the user.[What is Vpd](https://help.aliyun.com/document_detail/604976.html)

    > **NOTE:** Available in 1.201.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.eflo.get_vpds(ids=[default_alicloud_eflo_vpd["id"]],
        name_regex=default_alicloud_eflo_vpd["name"],
        vpd_name="RMC-Terraform-Test")
    pulumi.export("alicloudEfloVpdExampleId", default.vpds[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Vpd IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The Resource group id
    :param str status: The Vpd status. Valid values: `Available`, `Not Available`, `Executing`, `Deleting`,
    :param str vpd_id: The id of the vpd.
    :param str vpd_name: The Name of the VPD.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['vpdId'] = vpd_id
    __args__['vpdName'] = vpd_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eflo/getVpds:getVpds', __args__, opts=opts, typ=GetVpdsResult).value

    return AwaitableGetVpdsResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'),
        vpd_id=pulumi.get(__ret__, 'vpd_id'),
        vpd_name=pulumi.get(__ret__, 'vpd_name'),
        vpds=pulumi.get(__ret__, 'vpds'))
def get_vpds_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                    ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                    name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                    page_number: Optional[pulumi.Input[Optional[int]]] = None,
                    page_size: Optional[pulumi.Input[Optional[int]]] = None,
                    resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                    status: Optional[pulumi.Input[Optional[str]]] = None,
                    vpd_id: Optional[pulumi.Input[Optional[str]]] = None,
                    vpd_name: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVpdsResult]:
    """
    This data source provides Eflo Vpd available to the user.[What is Vpd](https://help.aliyun.com/document_detail/604976.html)

    > **NOTE:** Available in 1.201.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.eflo.get_vpds(ids=[default_alicloud_eflo_vpd["id"]],
        name_regex=default_alicloud_eflo_vpd["name"],
        vpd_name="RMC-Terraform-Test")
    pulumi.export("alicloudEfloVpdExampleId", default.vpds[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Vpd IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The Resource group id
    :param str status: The Vpd status. Valid values: `Available`, `Not Available`, `Executing`, `Deleting`,
    :param str vpd_id: The id of the vpd.
    :param str vpd_name: The Name of the VPD.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['vpdId'] = vpd_id
    __args__['vpdName'] = vpd_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eflo/getVpds:getVpds', __args__, opts=opts, typ=GetVpdsResult)
    return __ret__.apply(lambda __response__: GetVpdsResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        status=pulumi.get(__response__, 'status'),
        vpd_id=pulumi.get(__response__, 'vpd_id'),
        vpd_name=pulumi.get(__response__, 'vpd_name'),
        vpds=pulumi.get(__response__, 'vpds')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ApplicationAccessPointArgs', 'ApplicationAccessPoint']

@pulumi.input_type
class ApplicationAccessPointArgs:
    def __init__(__self__, *,
                 application_access_point_name: pulumi.Input[str],
                 policies: pulumi.Input[Sequence[pulumi.Input[str]]],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ApplicationAccessPoint resource.
        :param pulumi.Input[str] application_access_point_name: Application Access Point Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: The policies that have bound to the Application Access Point (AAP).
        :param pulumi.Input[str] description: Description .
        """
        pulumi.set(__self__, "application_access_point_name", application_access_point_name)
        pulumi.set(__self__, "policies", policies)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="applicationAccessPointName")
    def application_access_point_name(self) -> pulumi.Input[str]:
        """
        Application Access Point Name.
        """
        return pulumi.get(self, "application_access_point_name")

    @application_access_point_name.setter
    def application_access_point_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_access_point_name", value)

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The policies that have bound to the Application Access Point (AAP).
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description .
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ApplicationAccessPointState:
    def __init__(__self__, *,
                 application_access_point_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ApplicationAccessPoint resources.
        :param pulumi.Input[str] application_access_point_name: Application Access Point Name.
        :param pulumi.Input[str] description: Description .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: The policies that have bound to the Application Access Point (AAP).
        """
        if application_access_point_name is not None:
            pulumi.set(__self__, "application_access_point_name", application_access_point_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)

    @property
    @pulumi.getter(name="applicationAccessPointName")
    def application_access_point_name(self) -> Optional[pulumi.Input[str]]:
        """
        Application Access Point Name.
        """
        return pulumi.get(self, "application_access_point_name")

    @application_access_point_name.setter
    def application_access_point_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_access_point_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description .
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The policies that have bound to the Application Access Point (AAP).
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policies", value)


class ApplicationAccessPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_access_point_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a KMS Application Access Point resource. An application access point (AAP) is used to implement fine-grained access control for Key Management Service (KMS) resources. An application can access a KMS instance only after an AAP is created for the application. .

        For information about KMS Application Access Point and how to use it, see [What is Application Access Point](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createapplicationaccesspoint).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.kms.ApplicationAccessPoint("default",
            description="example aap",
            application_access_point_name=name,
            policies=[
                "abc",
                "efg",
                "hfc",
            ])
        ```

        ## Import

        KMS Application Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/applicationAccessPoint:ApplicationAccessPoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_access_point_name: Application Access Point Name.
        :param pulumi.Input[str] description: Description .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: The policies that have bound to the Application Access Point (AAP).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationAccessPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a KMS Application Access Point resource. An application access point (AAP) is used to implement fine-grained access control for Key Management Service (KMS) resources. An application can access a KMS instance only after an AAP is created for the application. .

        For information about KMS Application Access Point and how to use it, see [What is Application Access Point](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createapplicationaccesspoint).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.kms.ApplicationAccessPoint("default",
            description="example aap",
            application_access_point_name=name,
            policies=[
                "abc",
                "efg",
                "hfc",
            ])
        ```

        ## Import

        KMS Application Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/applicationAccessPoint:ApplicationAccessPoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationAccessPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationAccessPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_access_point_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationAccessPointArgs.__new__(ApplicationAccessPointArgs)

            if application_access_point_name is None and not opts.urn:
                raise TypeError("Missing required property 'application_access_point_name'")
            __props__.__dict__["application_access_point_name"] = application_access_point_name
            __props__.__dict__["description"] = description
            if policies is None and not opts.urn:
                raise TypeError("Missing required property 'policies'")
            __props__.__dict__["policies"] = policies
        super(ApplicationAccessPoint, __self__).__init__(
            'alicloud:kms/applicationAccessPoint:ApplicationAccessPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_access_point_name: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'ApplicationAccessPoint':
        """
        Get an existing ApplicationAccessPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_access_point_name: Application Access Point Name.
        :param pulumi.Input[str] description: Description .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] policies: The policies that have bound to the Application Access Point (AAP).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationAccessPointState.__new__(_ApplicationAccessPointState)

        __props__.__dict__["application_access_point_name"] = application_access_point_name
        __props__.__dict__["description"] = description
        __props__.__dict__["policies"] = policies
        return ApplicationAccessPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationAccessPointName")
    def application_access_point_name(self) -> pulumi.Output[str]:
        """
        Application Access Point Name.
        """
        return pulumi.get(self, "application_access_point_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description .
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence[str]]:
        """
        The policies that have bound to the Application Access Point (AAP).
        """
        return pulumi.get(self, "policies")

